@@ -30,14 +30,15 @@
  *
  * <b>Dispatcher Prototype</b>
  * \code
- * void volk_32fc_s32fc_x2_rotator_32fc(lv_32fc_t* outVector, const lv_32fc_t* inVector, const lv_32fc_t phase_inc, lv_32fc_t* phase, unsigned int num_points)
- * \endcode
+ * void volk_32fc_s32fc_x2_rotator_32fc(lv_32fc_t* outVector, const lv_32fc_t* inVector,
+ * const lv_32fc_t phase_inc, lv_32fc_t* phase, unsigned int num_points) \endcode
  *
  * \b Inputs
  * \li inVector: Vector to be rotated.
  * \li phase_inc: rotational velocity.
  * \li phase: initial phase offset.
- * \li num_points: The number of values in inVector to be rotated and stored into outVector.
+ * \li num_points: The number of values in inVector to be rotated and stored into
+ * outVector.
  *
  * \b Outputs
  * \li outVector: The vector where the results will be stored.
@@ -81,31 +82,38 @@
 #define INCLUDED_volk_32fc_s32fc_rotator_32fc_a_H
 
 
-#include <volk/volk_complex.h>
+#include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <math.h>
+#include <volk/volk_complex.h>
 #define ROTATOR_RELOAD 512
+#define ROTATOR_RELOAD_2 (ROTATOR_RELOAD / 2)
+#define ROTATOR_RELOAD_4 (ROTATOR_RELOAD / 4)
 
 
 #ifdef LV_HAVE_GENERIC
 
-static inline void volk_32fc_s32fc_x2_rotator_32fc_generic(lv_32fc_t* outVector, const lv_32fc_t* inVector, const lv_32fc_t phase_inc, lv_32fc_t* phase, unsigned int num_points){
+static inline void volk_32fc_s32fc_x2_rotator_32fc_generic(lv_32fc_t* outVector,
+                                                           const lv_32fc_t* inVector,
+                                                           const lv_32fc_t phase_inc,
+                                                           lv_32fc_t* phase,
+                                                           unsigned int num_points)
+{
     unsigned int i = 0;
     int j = 0;
-    for(i = 0; i < (unsigned int)(num_points/ROTATOR_RELOAD); ++i) {
-        for(j = 0; j < ROTATOR_RELOAD; ++j) {
+    for (i = 0; i < (unsigned int)(num_points / ROTATOR_RELOAD); ++i) {
+        for (j = 0; j < ROTATOR_RELOAD; ++j) {
             *outVector++ = *inVector++ * (*phase);
             (*phase) *= phase_inc;
         }
 
         (*phase) /= hypotf(lv_creal(*phase), lv_cimag(*phase));
     }
-    for(i = 0; i < num_points%ROTATOR_RELOAD; ++i) {
+    for (i = 0; i < num_points % ROTATOR_RELOAD; ++i) {
         *outVector++ = *inVector++ * (*phase);
         (*phase) *= phase_inc;
     }
-    if(i){
+    if (i) {
         // Make sure, we normalize phase on every call!
         (*phase) /= hypotf(lv_creal(*phase), lv_cimag(*phase));
     }
@@ -118,43 +126,47 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_generic(lv_32fc_t* outVector,
 #include <arm_neon.h>
 #include <volk/volk_neon_intrinsics.h>
 
-static inline void volk_32fc_s32fc_x2_rotator_32fc_neon(lv_32fc_t* outVector, const lv_32fc_t* inVector, const lv_32fc_t phase_inc, lv_32fc_t* phase, unsigned int num_points)
+static inline void volk_32fc_s32fc_x2_rotator_32fc_neon(lv_32fc_t* outVector,
+                                                        const lv_32fc_t* inVector,
+                                                        const lv_32fc_t phase_inc,
+                                                        lv_32fc_t* phase,
+                                                        unsigned int num_points)
 
 {
     lv_32fc_t* outputVectorPtr = outVector;
     const lv_32fc_t* inputVectorPtr = inVector;
     lv_32fc_t incr = 1;
-    lv_32fc_t phasePtr[4] = {(*phase), (*phase), (*phase), (*phase)};
+    lv_32fc_t phasePtr[4] = { (*phase), (*phase), (*phase), (*phase) };
     float32x4x2_t input_vec;
     float32x4x2_t output_vec;
-    
+
     unsigned int i = 0, j = 0;
-    const unsigned int quarter_points = num_points / 4;
-    
-    for(i = 0; i < 4; ++i) {
+    // const unsigned int quarter_points = num_points / 4;
+
+    for (i = 0; i < 4; ++i) {
         phasePtr[i] *= incr;
         incr *= (phase_inc);
     }
-    
+
     // Notice that incr has be incremented in the previous loop
-    const lv_32fc_t incrPtr[4] = {incr, incr, incr, incr};
-    const float32x4x2_t incr_vec = vld2q_f32((float*) incrPtr);
-    float32x4x2_t phase_vec = vld2q_f32((float*) phasePtr);
-    
-    for(i = 0; i < (unsigned int)(quarter_points/ROTATOR_RELOAD); i++) {
-        for(j = 0; j < ROTATOR_RELOAD; j++) {
-            input_vec = vld2q_f32((float*) inputVectorPtr);
+    const lv_32fc_t incrPtr[4] = { incr, incr, incr, incr };
+    const float32x4x2_t incr_vec = vld2q_f32((float*)incrPtr);
+    float32x4x2_t phase_vec = vld2q_f32((float*)phasePtr);
+
+    for (i = 0; i < (unsigned int)(num_points / ROTATOR_RELOAD); i++) {
+        for (j = 0; j < ROTATOR_RELOAD_4; j++) {
+            input_vec = vld2q_f32((float*)inputVectorPtr);
             // Prefetch next one, speeds things up
-            __VOLK_PREFETCH(inputVectorPtr+4);
+            __VOLK_PREFETCH(inputVectorPtr + 4);
             // Rotate
             output_vec = _vmultiply_complexq_f32(input_vec, phase_vec);
             // Increase phase
             phase_vec = _vmultiply_complexq_f32(phase_vec, incr_vec);
             // Store output
             vst2q_f32((float*)outputVectorPtr, output_vec);
-            
-            outputVectorPtr+=4;
-            inputVectorPtr+=4;
+
+            outputVectorPtr += 4;
+            inputVectorPtr += 4;
         }
         // normalize phase so magnitude doesn't grow because of
         // floating point rounding error
@@ -164,20 +176,20 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_neon(lv_32fc_t* outVector, co
         phase_vec.val[0] = vmulq_f32(phase_vec.val[0], inv_mag);
         phase_vec.val[1] = vmulq_f32(phase_vec.val[1], inv_mag);
     }
-    
-    for(i = 0; i < quarter_points % ROTATOR_RELOAD; i++) {
-        input_vec = vld2q_f32((float*) inputVectorPtr);
+
+    for (i = 0; i < (num_points % ROTATOR_RELOAD) / 4; i++) {
+        input_vec = vld2q_f32((float*)inputVectorPtr);
         // Prefetch next one, speeds things up
-        __VOLK_PREFETCH(inputVectorPtr+4);
+        __VOLK_PREFETCH(inputVectorPtr + 4);
         // Rotate
         output_vec = _vmultiply_complexq_f32(input_vec, phase_vec);
         // Increase phase
         phase_vec = _vmultiply_complexq_f32(phase_vec, incr_vec);
         // Store output
         vst2q_f32((float*)outputVectorPtr, output_vec);
-        
-        outputVectorPtr+=4;
-        inputVectorPtr+=4;
+
+        outputVectorPtr += 4;
+        inputVectorPtr += 4;
     }
     // if(i) == true means we looped above
     if (i) {
@@ -191,14 +203,14 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_neon(lv_32fc_t* outVector, co
     }
     // Store current phase
     vst2q_f32((float*)phasePtr, phase_vec);
-    
+
     // Deal with the rest
-    for(i = 0; i < num_points % 4; i++) {
+    for (i = 0; i < num_points % 4; i++) {
         *outputVectorPtr++ = *inputVectorPtr++ * phasePtr[0];
         phasePtr[0] *= (phase_inc);
     }
-    
-    // For continious phase next time we need to call this function
+
+    // For continuous phase next time we need to call this function
     (*phase) = phasePtr[0];
 }
 
@@ -208,32 +220,31 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_neon(lv_32fc_t* outVector, co
 #ifdef LV_HAVE_SSE4_1
 #include <smmintrin.h>
 
-static inline void volk_32fc_s32fc_x2_rotator_32fc_a_sse4_1(lv_32fc_t* outVector, const lv_32fc_t* inVector, const lv_32fc_t phase_inc, lv_32fc_t* phase, unsigned int num_points){
+static inline void volk_32fc_s32fc_x2_rotator_32fc_a_sse4_1(lv_32fc_t* outVector,
+                                                            const lv_32fc_t* inVector,
+                                                            const lv_32fc_t phase_inc,
+                                                            lv_32fc_t* phase,
+                                                            unsigned int num_points)
+{
     lv_32fc_t* cPtr = outVector;
     const lv_32fc_t* aPtr = inVector;
     lv_32fc_t incr = 1;
-    lv_32fc_t phase_Ptr[2] = {(*phase), (*phase)};
+    lv_32fc_t phase_Ptr[2] = { (*phase), (*phase) };
 
     unsigned int i, j = 0;
 
-    for(i = 0; i < 2; ++i) {
+    for (i = 0; i < 2; ++i) {
         phase_Ptr[i] *= incr;
         incr *= (phase_inc);
     }
 
-    /*printf("%f, %f\n", lv_creal(phase_Ptr[0]), lv_cimag(phase_Ptr[0]));
-    printf("%f, %f\n", lv_creal(phase_Ptr[1]), lv_cimag(phase_Ptr[1]));
-    printf("incr: %f, %f\n", lv_creal(incr), lv_cimag(incr));*/
     __m128 aVal, phase_Val, inc_Val, yl, yh, tmp1, tmp2, z, ylp, yhp, tmp1p, tmp2p;
 
     phase_Val = _mm_loadu_ps((float*)phase_Ptr);
-    inc_Val = _mm_set_ps(lv_cimag(incr), lv_creal(incr),lv_cimag(incr), lv_creal(incr));
+    inc_Val = _mm_set_ps(lv_cimag(incr), lv_creal(incr), lv_cimag(incr), lv_creal(incr));
 
-    const unsigned int halfPoints = num_points / 2;
-
-
-    for(i = 0; i < (unsigned int)(halfPoints/ROTATOR_RELOAD); i++) {
-        for(j = 0; j < ROTATOR_RELOAD; ++j) {
+    for (i = 0; i < (unsigned int)(num_points / ROTATOR_RELOAD); i++) {
+        for (j = 0; j < ROTATOR_RELOAD_2; ++j) {
 
             aVal = _mm_load_ps((float*)aPtr);
 
@@ -264,7 +275,7 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_a_sse4_1(lv_32fc_t* outVector
         tmp2 = _mm_sqrt_ps(tmp1);
         phase_Val = _mm_div_ps(phase_Val, tmp2);
     }
-    for(i = 0; i < halfPoints%ROTATOR_RELOAD; ++i) {
+    for (i = 0; i < (num_points % ROTATOR_RELOAD) / 2; ++i) {
         aVal = _mm_load_ps((float*)aPtr);
 
         yl = _mm_moveldup_ps(phase_Val);
@@ -304,7 +315,6 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_a_sse4_1(lv_32fc_t* outVector
     }
 
     (*phase) = phase_Ptr[0];
-
 }
 
 #endif /* LV_HAVE_SSE4_1 for aligned */
@@ -313,15 +323,20 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_a_sse4_1(lv_32fc_t* outVector
 #ifdef LV_HAVE_SSE4_1
 #include <smmintrin.h>
 
-static inline void volk_32fc_s32fc_x2_rotator_32fc_u_sse4_1(lv_32fc_t* outVector, const lv_32fc_t* inVector, const lv_32fc_t phase_inc, lv_32fc_t* phase, unsigned int num_points){
+static inline void volk_32fc_s32fc_x2_rotator_32fc_u_sse4_1(lv_32fc_t* outVector,
+                                                            const lv_32fc_t* inVector,
+                                                            const lv_32fc_t phase_inc,
+                                                            lv_32fc_t* phase,
+                                                            unsigned int num_points)
+{
     lv_32fc_t* cPtr = outVector;
     const lv_32fc_t* aPtr = inVector;
     lv_32fc_t incr = 1;
-    lv_32fc_t phase_Ptr[2] = {(*phase), (*phase)};
+    lv_32fc_t phase_Ptr[2] = { (*phase), (*phase) };
 
     unsigned int i, j = 0;
 
-    for(i = 0; i < 2; ++i) {
+    for (i = 0; i < 2; ++i) {
         phase_Ptr[i] *= incr;
         incr *= (phase_inc);
     }
@@ -332,13 +347,10 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_u_sse4_1(lv_32fc_t* outVector
     __m128 aVal, phase_Val, inc_Val, yl, yh, tmp1, tmp2, z, ylp, yhp, tmp1p, tmp2p;
 
     phase_Val = _mm_loadu_ps((float*)phase_Ptr);
-    inc_Val = _mm_set_ps(lv_cimag(incr), lv_creal(incr),lv_cimag(incr), lv_creal(incr));
+    inc_Val = _mm_set_ps(lv_cimag(incr), lv_creal(incr), lv_cimag(incr), lv_creal(incr));
 
-    const unsigned int halfPoints = num_points / 2;
-
-
-    for(i = 0; i < (unsigned int)(halfPoints/ROTATOR_RELOAD); i++) {
-        for(j = 0; j < ROTATOR_RELOAD; ++j) {
+    for (i = 0; i < (unsigned int)(num_points / ROTATOR_RELOAD); i++) {
+        for (j = 0; j < ROTATOR_RELOAD_2; ++j) {
 
             aVal = _mm_loadu_ps((float*)aPtr);
 
@@ -369,7 +381,7 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_u_sse4_1(lv_32fc_t* outVector
         tmp2 = _mm_sqrt_ps(tmp1);
         phase_Val = _mm_div_ps(phase_Val, tmp2);
     }
-    for(i = 0; i < halfPoints%ROTATOR_RELOAD; ++i) {
+    for (i = 0; i < (num_points % ROTATOR_RELOAD) / 2; ++i) {
         aVal = _mm_loadu_ps((float*)aPtr);
 
         yl = _mm_moveldup_ps(phase_Val);
@@ -409,7 +421,6 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_u_sse4_1(lv_32fc_t* outVector
     }
 
     (*phase) = phase_Ptr[0];
-
 }
 
 #endif /* LV_HAVE_SSE4_1 */
@@ -419,15 +430,20 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_u_sse4_1(lv_32fc_t* outVector
 #include <immintrin.h>
 #include <volk/volk_avx_intrinsics.h>
 
-static inline void volk_32fc_s32fc_x2_rotator_32fc_a_avx(lv_32fc_t* outVector, const lv_32fc_t* inVector, const lv_32fc_t phase_inc, lv_32fc_t* phase, unsigned int num_points){
+static inline void volk_32fc_s32fc_x2_rotator_32fc_a_avx(lv_32fc_t* outVector,
+                                                         const lv_32fc_t* inVector,
+                                                         const lv_32fc_t phase_inc,
+                                                         lv_32fc_t* phase,
+                                                         unsigned int num_points)
+{
     lv_32fc_t* cPtr = outVector;
     const lv_32fc_t* aPtr = inVector;
     lv_32fc_t incr = lv_cmake(1.0, 0.0);
-    lv_32fc_t phase_Ptr[4] = {(*phase), (*phase), (*phase), (*phase)};
+    lv_32fc_t phase_Ptr[4] = { (*phase), (*phase), (*phase), (*phase) };
 
     unsigned int i, j = 0;
 
-    for(i = 0; i < 4; ++i) {
+    for (i = 0; i < 4; ++i) {
         phase_Ptr[i] *= incr;
         incr *= (phase_inc);
     }
@@ -435,16 +451,18 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_a_avx(lv_32fc_t* outVector, c
     __m256 aVal, phase_Val, z;
 
     phase_Val = _mm256_loadu_ps((float*)phase_Ptr);
-    
-    const __m256 inc_Val = _mm256_set_ps(lv_cimag(incr), lv_creal(incr),
-                                         lv_cimag(incr), lv_creal(incr),
-                                         lv_cimag(incr), lv_creal(incr),
-                                         lv_cimag(incr), lv_creal(incr));
 
-    const unsigned int fourthPoints = num_points / 4;
+    const __m256 inc_Val = _mm256_set_ps(lv_cimag(incr),
+                                         lv_creal(incr),
+                                         lv_cimag(incr),
+                                         lv_creal(incr),
+                                         lv_cimag(incr),
+                                         lv_creal(incr),
+                                         lv_cimag(incr),
+                                         lv_creal(incr));
 
-    for(i = 0; i < (unsigned int)(fourthPoints/ROTATOR_RELOAD); i++) {
-        for(j = 0; j < ROTATOR_RELOAD; ++j) {
+    for (i = 0; i < (unsigned int)(num_points / ROTATOR_RELOAD); i++) {
+        for (j = 0; j < ROTATOR_RELOAD_4; ++j) {
 
             aVal = _mm256_load_ps((float*)aPtr);
 
@@ -458,8 +476,8 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_a_avx(lv_32fc_t* outVector, c
         }
         phase_Val = _mm256_normalize_ps(phase_Val);
     }
-    
-    for(i = 0; i < fourthPoints%ROTATOR_RELOAD; ++i) {
+
+    for (i = 0; i < (num_points % ROTATOR_RELOAD) / 4; ++i) {
         aVal = _mm256_load_ps((float*)aPtr);
 
         z = _mm256_complexmul_ps(aVal, phase_Val);
@@ -473,10 +491,10 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_a_avx(lv_32fc_t* outVector, c
     if (i) {
         phase_Val = _mm256_normalize_ps(phase_Val);
     }
-    
+
     _mm256_storeu_ps((float*)phase_Ptr, phase_Val);
     (*phase) = phase_Ptr[0];
-    volk_32fc_s32fc_x2_rotator_32fc_generic(cPtr, aPtr, phase_inc, phase, num_points%4);
+    volk_32fc_s32fc_x2_rotator_32fc_generic(cPtr, aPtr, phase_inc, phase, num_points % 4);
 }
 
 #endif /* LV_HAVE_AVX for aligned */
@@ -486,15 +504,20 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_a_avx(lv_32fc_t* outVector, c
 #include <immintrin.h>
 #include <volk/volk_avx_intrinsics.h>
 
-static inline void volk_32fc_s32fc_x2_rotator_32fc_u_avx(lv_32fc_t* outVector, const lv_32fc_t* inVector, const lv_32fc_t phase_inc, lv_32fc_t* phase, unsigned int num_points){
+static inline void volk_32fc_s32fc_x2_rotator_32fc_u_avx(lv_32fc_t* outVector,
+                                                         const lv_32fc_t* inVector,
+                                                         const lv_32fc_t phase_inc,
+                                                         lv_32fc_t* phase,
+                                                         unsigned int num_points)
+{
     lv_32fc_t* cPtr = outVector;
     const lv_32fc_t* aPtr = inVector;
     lv_32fc_t incr = lv_cmake(1.0, 0.0);
-    lv_32fc_t phase_Ptr[4] = {(*phase), (*phase), (*phase), (*phase)};
+    lv_32fc_t phase_Ptr[4] = { (*phase), (*phase), (*phase), (*phase) };
 
     unsigned int i, j = 0;
 
-    for(i = 0; i < 4; ++i) {
+    for (i = 0; i < 4; ++i) {
         phase_Ptr[i] *= incr;
         incr *= (phase_inc);
     }
@@ -502,19 +525,21 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_u_avx(lv_32fc_t* outVector, c
     __m256 aVal, phase_Val, z;
 
     phase_Val = _mm256_loadu_ps((float*)phase_Ptr);
-    
-    const __m256 inc_Val = _mm256_set_ps(lv_cimag(incr), lv_creal(incr),
-                                         lv_cimag(incr), lv_creal(incr),
-                                         lv_cimag(incr), lv_creal(incr),
-                                         lv_cimag(incr), lv_creal(incr));
-    
-    const unsigned int fourthPoints = num_points / 4;
 
-    for(i = 0; i < (unsigned int)(fourthPoints/ROTATOR_RELOAD); ++i) {
-        for(j = 0; j < ROTATOR_RELOAD; ++j) {
+    const __m256 inc_Val = _mm256_set_ps(lv_cimag(incr),
+                                         lv_creal(incr),
+                                         lv_cimag(incr),
+                                         lv_creal(incr),
+                                         lv_cimag(incr),
+                                         lv_creal(incr),
+                                         lv_cimag(incr),
+                                         lv_creal(incr));
+
+    for (i = 0; i < (unsigned int)(num_points / ROTATOR_RELOAD); ++i) {
+        for (j = 0; j < ROTATOR_RELOAD_4; ++j) {
 
             aVal = _mm256_loadu_ps((float*)aPtr);
-            
+
             z = _mm256_complexmul_ps(aVal, phase_Val);
             phase_Val = _mm256_complexmul_ps(phase_Val, inc_Val);
 
@@ -524,10 +549,9 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_u_avx(lv_32fc_t* outVector, c
             cPtr += 4;
         }
         phase_Val = _mm256_normalize_ps(phase_Val);
-        
     }
-    
-    for(i = 0; i < fourthPoints%ROTATOR_RELOAD; ++i) {
+
+    for (i = 0; i < (num_points % ROTATOR_RELOAD) / 4; ++i) {
         aVal = _mm256_loadu_ps((float*)aPtr);
 
         z = _mm256_complexmul_ps(aVal, phase_Val);
@@ -544,7 +568,7 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_u_avx(lv_32fc_t* outVector, c
 
     _mm256_storeu_ps((float*)phase_Ptr, phase_Val);
     (*phase) = phase_Ptr[0];
-    volk_32fc_s32fc_x2_rotator_32fc_generic(cPtr, aPtr, phase_inc, phase, num_points%4);
+    volk_32fc_s32fc_x2_rotator_32fc_generic(cPtr, aPtr, phase_inc, phase, num_points % 4);
 }
 
 #endif /* LV_HAVE_AVX */
@@ -552,15 +576,21 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_u_avx(lv_32fc_t* outVector, c
 #if LV_HAVE_AVX && LV_HAVE_FMA
 #include <immintrin.h>
 
-static inline void volk_32fc_s32fc_x2_rotator_32fc_a_avx_fma(lv_32fc_t* outVector, const lv_32fc_t* inVector, const lv_32fc_t phase_inc, lv_32fc_t* phase, unsigned int num_points){
+static inline void volk_32fc_s32fc_x2_rotator_32fc_a_avx_fma(lv_32fc_t* outVector,
+                                                             const lv_32fc_t* inVector,
+                                                             const lv_32fc_t phase_inc,
+                                                             lv_32fc_t* phase,
+                                                             unsigned int num_points)
+{
     lv_32fc_t* cPtr = outVector;
     const lv_32fc_t* aPtr = inVector;
     lv_32fc_t incr = 1;
-    __VOLK_ATTR_ALIGNED(32) lv_32fc_t phase_Ptr[4] = {(*phase), (*phase), (*phase), (*phase)};
+    __VOLK_ATTR_ALIGNED(32)
+    lv_32fc_t phase_Ptr[4] = { (*phase), (*phase), (*phase), (*phase) };
 
     unsigned int i, j = 0;
 
-    for(i = 0; i < 4; ++i) {
+    for (i = 0; i < 4; ++i) {
         phase_Ptr[i] *= incr;
         incr *= (phase_inc);
     }
@@ -568,11 +598,17 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_a_avx_fma(lv_32fc_t* outVecto
     __m256 aVal, phase_Val, inc_Val, yl, yh, tmp1, tmp2, z, ylp, yhp, tmp1p, tmp2p;
 
     phase_Val = _mm256_load_ps((float*)phase_Ptr);
-    inc_Val = _mm256_set_ps(lv_cimag(incr), lv_creal(incr),lv_cimag(incr), lv_creal(incr),lv_cimag(incr), lv_creal(incr),lv_cimag(incr), lv_creal(incr));
-    const unsigned int fourthPoints = num_points / 4;
+    inc_Val = _mm256_set_ps(lv_cimag(incr),
+                            lv_creal(incr),
+                            lv_cimag(incr),
+                            lv_creal(incr),
+                            lv_cimag(incr),
+                            lv_creal(incr),
+                            lv_cimag(incr),
+                            lv_creal(incr));
 
-    for(i = 0; i < (unsigned int)(fourthPoints/ROTATOR_RELOAD); i++) {
-        for(j = 0; j < ROTATOR_RELOAD; ++j) {
+    for (i = 0; i < (unsigned int)(num_points / ROTATOR_RELOAD); i++) {
+        for (j = 0; j < ROTATOR_RELOAD_4; ++j) {
 
             aVal = _mm256_load_ps((float*)aPtr);
 
@@ -603,7 +639,7 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_a_avx_fma(lv_32fc_t* outVecto
         tmp2 = _mm256_sqrt_ps(tmp1);
         phase_Val = _mm256_div_ps(phase_Val, tmp2);
     }
-    for(i = 0; i < fourthPoints%ROTATOR_RELOAD; ++i) {
+    for (i = 0; i < (num_points % ROTATOR_RELOAD) / 4; ++i) {
         aVal = _mm256_load_ps((float*)aPtr);
 
         yl = _mm256_moveldup_ps(phase_Val);
@@ -636,13 +672,12 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_a_avx_fma(lv_32fc_t* outVecto
     }
 
     _mm256_store_ps((float*)phase_Ptr, phase_Val);
-    for(i = 0; i < num_points%4; ++i) {
+    for (i = 0; i < num_points % 4; ++i) {
         *cPtr++ = *aPtr++ * phase_Ptr[0];
         phase_Ptr[0] *= (phase_inc);
     }
 
     (*phase) = phase_Ptr[0];
-
 }
 
 #endif /* LV_HAVE_AVX && LV_HAVE_FMA for aligned*/
@@ -650,15 +685,20 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_a_avx_fma(lv_32fc_t* outVecto
 #if LV_HAVE_AVX && LV_HAVE_FMA
 #include <immintrin.h>
 
-static inline void volk_32fc_s32fc_x2_rotator_32fc_u_avx_fma(lv_32fc_t* outVector, const lv_32fc_t* inVector, const lv_32fc_t phase_inc, lv_32fc_t* phase, unsigned int num_points){
+static inline void volk_32fc_s32fc_x2_rotator_32fc_u_avx_fma(lv_32fc_t* outVector,
+                                                             const lv_32fc_t* inVector,
+                                                             const lv_32fc_t phase_inc,
+                                                             lv_32fc_t* phase,
+                                                             unsigned int num_points)
+{
     lv_32fc_t* cPtr = outVector;
     const lv_32fc_t* aPtr = inVector;
     lv_32fc_t incr = 1;
-    lv_32fc_t phase_Ptr[4] = {(*phase), (*phase), (*phase), (*phase)};
+    lv_32fc_t phase_Ptr[4] = { (*phase), (*phase), (*phase), (*phase) };
 
     unsigned int i, j = 0;
 
-    for(i = 0; i < 4; ++i) {
+    for (i = 0; i < 4; ++i) {
         phase_Ptr[i] *= incr;
         incr *= (phase_inc);
     }
@@ -666,11 +706,17 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_u_avx_fma(lv_32fc_t* outVecto
     __m256 aVal, phase_Val, inc_Val, yl, yh, tmp1, tmp2, z, ylp, yhp, tmp1p, tmp2p;
 
     phase_Val = _mm256_loadu_ps((float*)phase_Ptr);
-    inc_Val = _mm256_set_ps(lv_cimag(incr), lv_creal(incr),lv_cimag(incr), lv_creal(incr),lv_cimag(incr), lv_creal(incr),lv_cimag(incr), lv_creal(incr));
-    const unsigned int fourthPoints = num_points / 4;
+    inc_Val = _mm256_set_ps(lv_cimag(incr),
+                            lv_creal(incr),
+                            lv_cimag(incr),
+                            lv_creal(incr),
+                            lv_cimag(incr),
+                            lv_creal(incr),
+                            lv_cimag(incr),
+                            lv_creal(incr));
 
-    for(i = 0; i < (unsigned int)(fourthPoints/ROTATOR_RELOAD); i++) {
-        for(j = 0; j < ROTATOR_RELOAD; ++j) {
+    for (i = 0; i < (unsigned int)(num_points / ROTATOR_RELOAD); i++) {
+        for (j = 0; j < ROTATOR_RELOAD_4; ++j) {
 
             aVal = _mm256_loadu_ps((float*)aPtr);
 
@@ -701,7 +747,7 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_u_avx_fma(lv_32fc_t* outVecto
         tmp2 = _mm256_sqrt_ps(tmp1);
         phase_Val = _mm256_div_ps(phase_Val, tmp2);
     }
-    for(i = 0; i < fourthPoints%ROTATOR_RELOAD; ++i) {
+    for (i = 0; i < (num_points % ROTATOR_RELOAD) / 4; ++i) {
         aVal = _mm256_loadu_ps((float*)aPtr);
 
         yl = _mm256_moveldup_ps(phase_Val);
@@ -734,13 +780,12 @@ static inline void volk_32fc_s32fc_x2_rotator_32fc_u_avx_fma(lv_32fc_t* outVecto
     }
 
     _mm256_storeu_ps((float*)phase_Ptr, phase_Val);
-    for(i = 0; i < num_points%4; ++i) {
+    for (i = 0; i < num_points % 4; ++i) {
         *cPtr++ = *aPtr++ * phase_Ptr[0];
         phase_Ptr[0] *= (phase_inc);
     }
 
     (*phase) = phase_Ptr[0];
-
 }
 
 #endif /* LV_HAVE_AVX && LV_HAVE_FMA*/
